## Tautomer patterns

- `smirks_transform_all.txt`

Reference:

D. K. Dhaked, W.-D. Ihlenfeldt, H. Patel, V. Delannée, M. C. Nicklaus, 
Toward a Comprehensive Treatment of Tautomerism in Chemoinformatics Including in InChI V2. 
J. Chem. Inf. Model. (2020). https://doi.org/10.1021/acs.jcim.9b01080.

https://github.com/xundrug/moltaut

a set of 86 transform rules expressed in SMIRKS


## RDKit's TautomerEnumerator

Reference:

M. Sitzmann, W.-D. Ihlenfeldt, M. C. Nicklaus, Tautomerism in large databases. 
J. Comput. Aided Mol. Des. 24, 521-551 (2010).

a set of 21 transform rules expressed in SMIRKS
